function [Int, Mint] = fem2d_lin_int(u, ptable, eltable, Mint)
%
% Computes the integral of linear triangle element function given
% by coefficient vector u
%
% Uniform triangular mesh with lexikographical ordering (x-direction first)
%
%  10--11--12
%   | / | / |
%   |/  |/  |
%   7---8---9
%   | / | / |
%   |/  |/  |
%   4---5---6
%   | / | / |
%   |/  |/  |
%   1---2---3
%
%
%   INPUT      Description                                         Size
%  
%   u          vector of d.o.f. coefficients of FE function        np x 1
%
%   ptable     matrix containing coordiantes of mesh vertices      2 x np
%
%   eltable    element table containing global indices of local    3 x nel
%              nodes of each triangle element
%            
%   Mint     Vector with integral values of FE basis functions
%              (optinal, np x 1)
%
%   OUTPUT 
%
%   Int             Integral value of FE function u                      1 x 1
%
%   Mint           Vector with integral values of FE basis functions N x 1
%
%

if nargin < 4
    %% Compute global integral vector

    % Total number of d.o.f.s (=nodes)
    N = ;

    % Mesh infos: spacing in x- and y- direction
    hx = ...;
    nx = ...; % number of rectangles in x direction
    hy = abs(ptable(2,nx+2) - ptable(2,1));

    % Determinant of matrix B of affine mapping 
    % x = B*xi + b from reference to physical to element
    detB = ... ;       % determinant of B 

    % Vector of integral values of local basis functions
    M_loc = ...;
    
    % Vector of integral values of global basis functions
    Mint = zeros(N,1);
    n_el = ...; % number of elements
    for ...,
        ...
    end
end

%% Compute integral
Int = Mint' * u;

end

