function [] = fem2d_lin_plot(u, ptable, eltable)
%
% This function generates surface-contour plot for a function given by its 
% values at the nodes on a uniform reactangular grid with lexikographic
% ordering (x-direction first)
%
%  10--11--12
%   |   |   |
%   |   |   |
%   7---8---9
%   |   |   |
%   |   |   |
%   4---5---6
%   |   |   |
%   |   |   |
%   1---2---3
%
%   INPUT      Description                                         Size
%  
%   u          function values at grid points                     nx*ny x 1
%
%   ptable     matrix containing coordiantes of mesh vertices      2 x np
%
%   eltable    element table containing global indices of local    3 x nel
%              nodes of each triangle element
%

% Mesh widths
hx = abs(ptable(1,2) - ptable(1,1));
L = max(ptable(1,:));
nx = 1+L/hx; 
hy = abs(ptable(2,nx+2) - ptable(2,1));
H = max(ptable(2,:));
ny = 1+H/hy;

% x- and y-coordinates
x = 0:hx:L; y = 0:hy:H;

% surface-contour plot
[XX,YY] = meshgrid(x,y);
surfc(XX,YY,reshape(u,nx,ny)','LineStyle','none');
xlabel('x'); ylabel('y');
end

